bluemath\_tk.core.plotting package
==================================

Submodules
----------

bluemath\_tk.core.plotting.base\_plotting module
------------------------------------------------

.. automodule:: bluemath_tk.core.plotting.base_plotting
   :members:
   :undoc-members:
   :show-inheritance:

bluemath\_tk.core.plotting.colors module
----------------------------------------

.. automodule:: bluemath_tk.core.plotting.colors
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: bluemath_tk.core.plotting
   :members:
   :undoc-members:
   :show-inheritance:
